//-----------------------------------------------------------------------------
//
//						XMM Science Analysis System (SAS)
//					   (c) 1997-2010 European Space Agency
//
//-----------------------------------------------------------------------------
//
//	PreferenceMenu.cc --- implementation of PreferenceMenu classes
//
//	DESCRIPTION:
//		This implements all PreferenceMenu classes
//
//	CHANGE HISTORY:
//		UL, 2000-10-09: 1.0.0: - first version
//
//	AUTHOR:
//		U. Lammers, Mon Oct  9 13:37:19 MET DST 2000
//
//	REFERENCES:
//		[1]: Software Specification Document for the XMM Science Analysis
//			 Subsystem, M. Dahlem et. al.,
//
//	$Header: /data/xmm12/cvsadmin/soc_repos/sas/packages/preferences/src/PreferenceMenu.cc,v 1.2 2000/10/25 16:00:02 ulammers Exp $
//

#include <iostream>
#include <qdialog.h>
#include <qlayout.h>
#include <qlineedit.h>
#include <qmenudata.h>
#include "PreferenceMenu.h"

//
//	---( PreferencePopupMenu )------------------------------------------------
//
PreferencePopupMenu::PreferencePopupMenu(QWidget *parent,
										 const PreferenceGroup &group)
	: QPopupMenu(parent, group.name().c_str())
{
	PROC

	populateMenu(this, group.name(), this, group);

	ENDPROC
} // PreferencePopupMenu::PreferencePopupMenu()


void PreferencePopupMenu::populateMenu(QPopupMenu *menu,
									   const string &path,
									   QObject *receiver,
									   const PreferenceGroup &group)
{
	PROC

	vector<PrefMapIterator> prefValues(group.valuePreferences()),
							prefGroups(group.groupPreferences());
	unsigned Nprefs = prefValues.size(),
			 Ngroups = prefGroups.size();
							

	//
	//	first insert all value preferences
	//
	for (unsigned n=0; n<Nprefs; ++n) {
		_prefs.push_back(PrefItem(path + "." + prefValues[n]->first,
								  prefValues[n]->second->value()));
		int id = menu->insertItem(prefValues[n]->first.c_str(), receiver,
						 SLOT(entrySelected(int)), 0, _prefs.size()-1);
		QMenuData::setWhatsThis(id, _prefs[id].second.c_str());
	}

	if (Nprefs && Ngroups)
		menu->insertSeparator();

	//
	//	now insert all group preferences
	//
	for (unsigned n=0; n<Ngroups; ++n) {
		QPopupMenu *subMenu = new QPopupMenu();
		const PreferenceGroup *p = prefGroups[n]->second->group();
		populateMenu(subMenu, path + "." + p->name(), receiver, *p);
		menu->insertItem(prefGroups[n]->first.c_str(), subMenu);
	}

	ENDPROC
} // PreferencePopupMenu::populateMenu()


void PreferencePopupMenu::entrySelected(int id)
{
	emit preferenceValue(_prefs[id].first, _prefs[id].second);
} // PreferencePopupMenu::entrySelected()


PreferencePopupMenu::~PreferencePopupMenu()
{
	PROC
	ENDPROC
} // PreferencePopupMenu::~PreferencePopupMenu()


//
//	---( PreferenceButtonMenu )-----------------------------------------------
//
PreferenceButtonMenu::PreferenceButtonMenu(QWidget *parent,
										   const PreferenceGroup &group)
	: QPushButton(group.name().c_str(), parent)
{
	_prefMenu = new PreferencePopupMenu(this, group);
	setPopup(_prefMenu);
} // PreferenceButtonMenu::PreferenceButtonMenu()


PreferenceButtonMenu::~PreferenceButtonMenu()
{
	delete _prefMenu;
} // PreferenceButtonMenu::~PreferenceButtonMenu()
