//-----------------------------------------------------------------------------
//
//						XMM Science Analysis System (SAS)
//					   (c) 1997-2010 European Space Agency
//
//-----------------------------------------------------------------------------
//
//	PreferenceMenu.h --- display a preference hierachy as a menu tree
//
//	DESCRIPTION:
//		A preference group is displayed as a cascaded hierachy of popup
//		menus. The preference key is displayed as menu text
//
//	CHANGE HISTORY:
//		UL, 2000-10-09: 1.0.0: - first version
//
//	AUTHOR:
//		U. Lammers, Mon Oct  9 13:37:19 MET DST 2000
//
//	REFERENCES:
//		[1]: Software Specification Document for the XMM Science Analysis
//			 Subsystem, M. Dahlem et. al.,
//
//	$Header: /data/xmm12/cvsadmin/soc_repos/sas/packages/preferences/src/PreferenceMenu.h,v 1.2 2000/10/25 16:00:03 ulammers Exp $
//
#ifndef PREFERENCE_MENU_H
#define PREFERENCE_MENU_H

#include <qpopupmenu.h>
#include <qpushbutton.h>
#include <qmenubar.h>

#include "Preferences.h"
#include "Tracer.h"
#include "stringutil.h"
#include "errstr.h"

//
//	---( PreferencePopupMenu )------------------------------------------------
//
class PreferencePopupMenu : public QPopupMenu {
	Q_OBJECT

public:
	PreferencePopupMenu(QWidget *parent, const PreferenceGroup &group);
		//
		//	PURPOSE:
		//		Construct a PreferencePopupMenu; the menu entries are
		//		labeled with the preference names; values are emitted
		//		via signals upon selection
		//
		//	ARGUMENTS:
		//		parent	: parent widget
		//		group	: preference group to display
		//


	~PreferencePopupMenu();
		//	PURPOSE:
		//		Destroy PreferencePopupMenu
		//

signals:
	void preferenceValue(const string &prefPath, const PreferenceValue &value);
		//
		//	PURPOSE:
		//		Signal is emitted when a menu item is selected.
		//
		//	ARGUMENTS:
		//		prefPath	: fully qualified name of selected preference
		//					  item
		//		value		: value of selected preference
		//

private slots:
	void entrySelected(int id);

private:
	void populateMenu(QPopupMenu *menu, const string &path,
					  QObject *receiver, const PreferenceGroup &group);

private:
	typedef pair<string, PreferenceValue>	PrefItem;
	//			 path    value
	vector<PrefItem>		_prefs;
};


//
//	---( PreferenceButtonMenu )-----------------------------------------------
//
//	The PreferencePopupMenu is bound to a push button selection of which
//	triggers the activation of the popup menu at the position of the
//	button.
//
class PreferenceButtonMenu : public QPushButton {
	Q_OBJECT

public:
	PreferenceButtonMenu(QWidget *parent, const PreferenceGroup &group);
		//
		//	PURPOSE:
		//		Construct PreferencePopupMenu bound to a push button;
		//		button will be labeled with group name.
		//
		//	ARGUMENTS:
		//		parent	: parent widget
		//		group	: preference group to display
		//


	PreferencePopupMenu *popup() const { PROC RETURN _prefMenu; }
		//
		//	PURPOSE:
		//		Gives access to underlying PreferencePopupMenu.
		//


	~PreferenceButtonMenu();
		//
		//	Destroy PreferenceButtonMenu.
		//

private:
	PreferencePopupMenu	*_prefMenu;
};

#endif
