//-----------------------------------------------------------------------------
//
//						XMM Science Analysis System (SAS)
//					   (c) 1997-2010 European Space Agency
//
//-----------------------------------------------------------------------------
//
//	TaskPreferences.h --- preferences for SAS tasks
//
//	DESCRIPTION:
//		A TaskPreferenceGroup object is a PreferenceGroup initialized
//		from a task preference file.
//
//	CHANGE HISTORY:
//		UL, 2000-10-17: 1.0.0: - first version
//
//	AUTHOR:
//		U. Lammers, Tue Oct 17 17:30:10 MET DST 2000
//
//	REFERENCES:
//		[1]: Software Specification Document for the XMM Science Analysis
//			 Subsystem, M. Dahlem et. al.,
//
//	$Header: /data/xmm12/cvsadmin/soc_repos/sas/packages/preferences/src/TaskPreferences.h,v 1.2 2000/10/26 13:43:00 ulammers Exp $
//

#ifndef TASK_PREFERENCES_H
#define TASK_PREFERENCES_H

#include <string>
#include "Preferences.h"

//
//	---( TaskPreference )---------------------------------------------------
//
class TaskPreferenceGroup : public PreferenceGroup {
public:
	static const char *const sasPrefFileName = ".sas.pref";

	explicit TaskPreferenceGroup(const string &taskName);
		//
		//	PURPOSE:
		//		Create TaskPreferenceGroup object; the PreferenceGroup
		//		is initialized from a preference group with name <taskName>
		//		in the preference file
		//			$HOME/<sasPrefFileName>
		//
		//	ARGUMENTS:
		//		name	: name of the task; if it is empty the entire
		//				  contents of $HOME/<sasPrefFile> will be considered
		//


	~TaskPreferenceGroup();
		//
		//	PURPOSE:
		//		Destroy object.
		//
};

#endif
